@@ -1,4 +1,4 @@
 from .absent import ABSENT, Absent
 from .api_base import ApiBase
 from .params import ParamDirection, ParamLocation, ParamPlacement
-from .security import ApiKeyAuth
+from .security import ApiKeyAuth, HTTPAuth
