@@ -1,14 +1,16 @@
-import typing
-from typing import Optional, Type, Generator, TypeVar, cast
+import inspect
+from collections.abc import Mapping, Generator
+from typing import Optional, Type, TypeVar, cast
 
 import httpx
 import pydantic
 
+from .http_consts import CONTENT_TYPE
 from .mime import find_mime
 
 T = TypeVar('T')
 
-MimeMap = typing.Mapping[str, Type[T]]
+MimeMap = Mapping[str, Type[T]]
 ResponseMap = dict[str, MimeMap]
 
 
@@ -25,7 +27,10 @@ def _handle_response(
         response.raise_for_status()
         return response.content
 
-    obj = parse_model(response, cast(Type[T], typ))
+    try:
+        obj = parse_model(response, cast(Type[T], typ))
+    except pydantic.ValidationError:
+        raise ValueError(response.content)
 
     if isinstance(obj, Exception):
         raise obj
@@ -34,10 +39,10 @@ def _handle_response(
 
 
 def parse_model(response: httpx.Response, typ: Type[T]) -> T:
-    if hasattr(typ, 'mro'):
-        if Exception in typ.mro():
+    if inspect.isclass(typ):
+        if issubclass(typ, Exception):
             return typ(response.json())
-        elif pydantic.BaseModel in typ.mro():
+        elif issubclass(typ, pydantic.BaseModel):
             return typ.parse_raw(response.content)
 
     return pydantic.parse_raw_as(typ, response.content)
@@ -45,7 +50,9 @@ def parse_model(response: httpx.Response, typ: Type[T]) -> T:
 
 def find_type(response: httpx.Response, response_map, global_response_map) -> Optional[Type]:
     status_code = str(response.status_code)
-    content_type = response.headers.get('content-type', None)
+    if CONTENT_TYPE not in response.headers:
+        return None
+    content_type = response.headers[CONTENT_TYPE]
 
     if content_type is None:
         return None
